@@ -5,23 +5,23 @@ import os
 import sys
 import tempfile
 
-from wwpdb.utils.dp.electron_density.common_functions import run_command_and_check_output_file, \
-    convert_mdb_to_binary_cif
+from wwpdb.utils.dp.electron_density.common_functions import run_command_and_check_output_file, convert_mdb_to_binary_cif
 
 logger = logging.getLogger(__name__)
 
 
 class XrayVolumeServerMap:
-    def __init__(self,
-                 coord_path,
-                 binary_map_out,
-                 node_path,
-                 volume_server_pack_path,
-                 volume_server_query_path,
-                 working_dir,
-                 two_fofc_mmcif_map_coeff_in,
-                 fofc_mmcif_map_coeff_in,
-                 ):
+    def __init__(
+        self,
+        coord_path,
+        binary_map_out,
+        node_path,
+        volume_server_pack_path,
+        volume_server_query_path,
+        working_dir,
+        two_fofc_mmcif_map_coeff_in,
+        fofc_mmcif_map_coeff_in,
+    ):
         self.coord_path = coord_path
         self.binary_map_out = binary_map_out
         self.node_path = node_path
@@ -32,7 +32,7 @@ class XrayVolumeServerMap:
         self.fofc_mmcif_map_coeff_in = fofc_mmcif_map_coeff_in
 
         # intermediate files
-        self.mdb_map_path = os.path.join(self.working_dir, 'mdb_map.mdb')
+        self.mdb_map_path = os.path.join(self.working_dir, "mdb_map.mdb")
         self.two_fo_fc_map = os.path.join(self.working_dir, "2fofc.map")
         self.fo_fc_map = os.path.join(self.working_dir, "fofc.map")
 
@@ -79,10 +79,7 @@ class XrayVolumeServerMap:
             if os.path.exists(sf_mmcif_in):
                 doc = gemmi.cif.read(sf_mmcif_in)  # pylint: disable=no-member
                 rblocks = gemmi.as_refln_blocks(doc)
-                if (
-                        f_column in rblocks[0].column_labels()
-                        and phi_column in rblocks[0].column_labels()
-                ):
+                if f_column in rblocks[0].column_labels() and phi_column in rblocks[0].column_labels():
                     ccp4 = gemmi.Ccp4Map()
                     ccp4.grid = rblocks[0].transform_f_phi_to_map(f_column, phi_column)
                     ccp4.update_ccp4_header(2, True)
@@ -94,8 +91,7 @@ class XrayVolumeServerMap:
                     else:
                         logger.error("output map file {} missing".format(map_out))  # pylint: disable=logging-format-interpolation)
                 else:
-                    logger.error(
-                        "{} {} columns not found in mmCIF {}".format(f_column, phi_column, sf_mmcif_in))  # pylint: disable=logging-format-interpolation
+                    logger.error("{} {} columns not found in mmCIF {}".format(f_column, phi_column, sf_mmcif_in))  # pylint: disable=logging-format-interpolation
             else:
                 logger.error("cannot find input file {}".format(sf_mmcif_in))  # pylint: disable=logging-format-interpolation)
 
@@ -105,12 +101,12 @@ class XrayVolumeServerMap:
         return False
 
     def make_maps_to_serve_with_volume_server(
-            self,
-            two_fofc_map_in,
-            fofc_map_in,
+        self,
+        two_fofc_map_in,
+        fofc_map_in,
     ):
         if not self.node_path:
-            logger.error('node path not set')
+            logger.error("node path not set")
             return False
         if self.volume_server_pack_path:
             return self.make_volume_server_map(
@@ -120,9 +116,7 @@ class XrayVolumeServerMap:
         else:
             return False
 
-    def make_volume_server_map(
-            self, two_fofc_map_in, fofc_map_in
-    ):
+    def make_volume_server_map(self, two_fofc_map_in, fofc_map_in):
         """
         make map for Volume server to serve
         :param: map_in: input map file
@@ -130,40 +124,39 @@ class XrayVolumeServerMap:
         :return: True if worked, False if failed
         """
         if not self.node_path:
-            logger.error('node path not set')
+            logger.error("node path not set")
             return False
         if not self.volume_server_pack_path:
             logger.error("volume server executable not set")
             return False
         if not os.path.exists(self.volume_server_pack_path):
-            logger.error(
-                "volume server executable not found at {}".format(self.volume_server_pack_path))  # pylint: disable=logging-format-interpolation
+            logger.error("volume server executable not found at {}".format(self.volume_server_pack_path))  # pylint: disable=logging-format-interpolation
             return False
         if os.path.exists(two_fofc_map_in) and os.path.exists(fofc_map_in):
-            command = "{} {} xray {} {} {}".format(
-                self.node_path, self.volume_server_pack_path, two_fofc_map_in, fofc_map_in, self.mdb_map_path
-            )
-            return run_command_and_check_output_file(command=command, workdir=None, process_name='make mdb_map',
-                                                     output_file=self.mdb_map_path)
+            command = "{} {} xray {} {} {}".format(self.node_path, self.volume_server_pack_path, two_fofc_map_in, fofc_map_in, self.mdb_map_path)
+            return run_command_and_check_output_file(command=command, workdir=None, process_name="make mdb_map", output_file=self.mdb_map_path)
 
     def convert_mdb_map_to_binary_cif(self):
-        return convert_mdb_to_binary_cif(map_id='x_ray_volume', source_id='x-ray',
-                                         output_file=self.binary_map_out,
-                                         working_dir=self.working_dir,
-                                         mdb_map_path=self.mdb_map_path,
-                                         volume_server_query_path=self.volume_server_query_path,
-                                         node_path=self.node_path,
-                                         detail=4)
+        return convert_mdb_to_binary_cif(
+            map_id="x_ray_volume",
+            source_id="x-ray",
+            output_file=self.binary_map_out,
+            working_dir=self.working_dir,
+            mdb_map_path=self.mdb_map_path,
+            volume_server_query_path=self.volume_server_query_path,
+            node_path=self.node_path,
+            detail=4,
+        )
 
 
 def run_process_with_gemmi(
-        node_path,
-        coord_file,
-        two_fofc_mmcif_map_coeff_in,
-        fofc_mmcif_map_coeff_in,
-        binary_map_out,
-        volume_server_pack_path=None,
-        volume_server_query_path=None,
+    node_path,
+    coord_file,
+    two_fofc_mmcif_map_coeff_in,
+    fofc_mmcif_map_coeff_in,
+    binary_map_out,
+    volume_server_pack_path=None,
+    volume_server_query_path=None,
 ):
     """
     Process 2fo-fc and fo-fc mmCIF files and convert to maps for volume server
@@ -183,32 +176,33 @@ def run_process_with_gemmi(
         return False
 
     if not coord_file:
-        logger.error('coordinate file must be provided')
+        logger.error("coordinate file must be provided")
         return False
 
     if not node_path:
-        logger.error('node not set')
+        logger.error("node not set")
         return False
 
     if not os.path.exists(node_path):
-        logger.error('node not found: {}'.format(node_path))  # pylint: disable=logging-format-interpolation
+        logger.error("node not found: {}".format(node_path))  # pylint: disable=logging-format-interpolation
         return False
 
     if not os.path.exists(two_fofc_mmcif_map_coeff_in) or not os.path.exists(fofc_mmcif_map_coeff_in):
-        logger.error(
-            'input mmcif files not found: {} or {}'.format(two_fofc_mmcif_map_coeff_in, fofc_mmcif_map_coeff_in))  # pylint: disable=logging-format-interpolation)
+        logger.error("input mmcif files not found: {} or {}".format(two_fofc_mmcif_map_coeff_in, fofc_mmcif_map_coeff_in))  # pylint: disable=logging-format-interpolation)
         return False
 
     run_working_directory = tempfile.mkdtemp()
     logger.debug("working directory: {}".format(run_working_directory))  # pylint: disable=logging-format-interpolation
-    xrsm = XrayVolumeServerMap(coord_path=coord_file,
-                               node_path=node_path,
-                               volume_server_pack_path=volume_server_pack_path,
-                               binary_map_out=binary_map_out,
-                               working_dir=run_working_directory,
-                               two_fofc_mmcif_map_coeff_in=two_fofc_mmcif_map_coeff_in,
-                               fofc_mmcif_map_coeff_in=fofc_mmcif_map_coeff_in,
-                               volume_server_query_path=volume_server_query_path)
+    xrsm = XrayVolumeServerMap(
+        coord_path=coord_file,
+        node_path=node_path,
+        volume_server_pack_path=volume_server_pack_path,
+        binary_map_out=binary_map_out,
+        working_dir=run_working_directory,
+        two_fofc_mmcif_map_coeff_in=two_fofc_mmcif_map_coeff_in,
+        fofc_mmcif_map_coeff_in=fofc_mmcif_map_coeff_in,
+        volume_server_query_path=volume_server_query_path,
+    )
     return xrsm.run_process()
 
 
@@ -236,9 +230,7 @@ def main():  # pragma: no cover
     parser.add_argument("--coordinate_file", help="mmCIF coordinate file", type=str, required=True)
     parser.add_argument("--volume_server_pack_path", help="volume-server-pack path", type=str, required=True)
     parser.add_argument("--volume_server_query_path", help="volume-server-query path", type=str, required=True)
-    parser.add_argument(
-        "--keep_working", help="Keep working directory", action="store_true"
-    )
+    parser.add_argument("--keep_working", help="Keep working directory", action="store_true")
     parser.add_argument(
         "-d",
         "--debug",
@@ -260,7 +252,7 @@ def main():  # pragma: no cover
         two_fofc_mmcif_map_coeff_in=args.two_fofc_mmcif_map_coeff_in,
         fofc_mmcif_map_coeff_in=args.fofc_mmcif_map_coeff_in,
         coord_file=args.coordinate_file,
-        binary_map_out=args.binary_map_out
+        binary_map_out=args.binary_map_out,
     )
 
     if not ok:
